@@ -16,6 +16,18 @@ stoneSuit=function(value, crop="wheat"){
   else if(crop=="lentil"){suitclass=ifelse(value<3,1,ifelse(value<15,2,ifelse(value<35,3,4)))}
   else if(crop=="soybean"){suitclass=ifelse(value<3,1,ifelse(value<15,2,ifelse(value<35,3,4)))}
 
+  #Soil stonniness % suitability classes for forests
+  else if(crop=="poplar"){suitclass=ifelse(value<3,1,ifelse(value<15,2,ifelse(value<35,3,4)))}
+  else if(crop=="grevillea"){suitclass=ifelse(value<3,1,ifelse(value<15,2,ifelse(value<35,3,4)))}
+  else if(crop=="sesbania"){suitclass=ifelse(value<3,1,ifelse(value<15,2,ifelse(value<35,3,4)))}
+  else if(crop=="calliandra"){suitclass=ifelse(value<3,1,ifelse(value<15,2,ifelse(value<35,3,4)))}
+  else if(crop=="leucaena"){suitclass=ifelse(value<3,1,ifelse(value<15,2,ifelse(value<35,3,4)))}
+  else if(crop=="acacia"){suitclass=ifelse(value<3,1,ifelse(value<15,2,ifelse(value<35,3,4)))}
+  else if(crop=="eucalyptus"){suitclass=ifelse(value<3,1,ifelse(value<15,2,ifelse(value<35,3,4)))}
+  else if(crop=="teak"){suitclass=ifelse(value<3,1,ifelse(value<15,2,ifelse(value<35,3,4)))}
+  else if(crop=="maple"){suitclass=ifelse(value<3,1,ifelse(value<15,2,ifelse(value<35,3,4)))}
+  else if(crop=="ash"){suitclass=ifelse(value<3,1,ifelse(value<15,2,ifelse(value<35,3,4)))}
+  
   #Soil stonniness % suitability classes for oilcrops
   else if(crop=="sesame"){suitclass=ifelse(value<15,1,ifelse(value<25,2,ifelse(value<35,3,4)))}
   else if(crop=="sunflower"){suitclass=ifelse(value<3,1,ifelse(value<15,2,ifelse(value<35,3,4)))}
